/* Provided by the Sphinx base theme template at build time */
@import "../basic.css";
@import url('https://fonts.googleapis.com/css2?family=Inconsolata:wght@600&display=swap');


@font-face {
    font-family: "Source Sans Pro Light";
    src: url(../fonts/SourceSansPro-Light.ttf);
}

@font-face {
    font-family: "Source Sans Pro";
    src: url(../fonts/SourceSansPro-Regular.ttf);
}

:root {
  /* Ansys specific changes to the theme */

  /*****************************************************************************
  * Ansys Font family
  **/
  /* These are adapted from https://systemfontstack.com/ */
  --pst-font-family-base-system: -apple-system, BlinkMacSystemFont, Segoe UI, "Helvetica Neue",
    Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol;
  --pst-font-family-monospace-system: "SFMono-Regular", Menlo, Consolas, Monaco,
    Liberation Mono, Lucida Console, monospace;

  --pst-font-family-base: 'Source Sans Pro', sans-serif, var(--pst-font-family-base-system);
  --pst-font-family-heading: 'Source Sans Pro', sans-serif, var(--pst-font-family-base-system);
  --pst-font-family-monospace: Courier, var(--pst-font-family-monospace-system);

  /*****************************************************************************
  * Ansys compatible colors
  * 
  * Colors are defined in rgb string way, "red, green, blue"
  **/
  --ansysGold: 255, 183, 27; /* #FFB71B */
  --ansysBronze: 200, 146, 17; /* #C89211 */
  --pythonBlue: 57, 114, 161; /* #3972a1 */

  --pst-color-active-navigation: 200, 146, 17;  /* --ansysBronze */
  --pst-color-navbar-link: 255, 255, 255;
  --pst-color-navbar-link-hover: 255, 183, 27;  /* --ansysBronze */
  --pst-color-navbar-link-active: 255, 183, 27;  /* --ansysBronze */

}

.docutils {
    color: #C89211;
    font-family: 'Inconsolata';
    font-weight: bold;
    font-size: 107%;
}

.xref.std.std-ref {
    color: #C89211;
    font-family: 'Inconsolata';
    font-weight: bold;
    font-style: italic;
    font-size: 107%;
}

.sig-prename {
    color: #C89211;
    font-family: 'Source Sans Pro', sans-serif;
}

.sig-name.descname {
    color: #C89211;
    /* font-family: '   Source Sans Pro', sans-serif; */
}

.sig-name {
    color: #C89211;
    font-family: 'Source Sans Pro', sans-serif;
}

/* make the github logo white */
i.fa-github-square:before {
    color: #ffffff !important;
}

/* Increase empty-space around classes, methods, properties, etc. that are descendants
 of other items */
dl.class dl.py {
    margin-top: 2.5em;
    margin-bottom: 2.5em;
}

/* Reduce empty-space around Notes and Examples headings */
p.rubric {
    margin-top: 0.75em;
    margin-bottom: 0.75em;
}



/*
###############
   table 
###############
*/

table {
  width:100%;
  max-width: 100%; 
  border-spacing: 0;
  border-collapse: collapse;
  overflow: hidden;
  vertical-align: middle;

  /* Disabling scroll bars */
  overflow-y: scroll;
  scrollbar-width: none; /* Firefox */
  -ms-overflow-style: none;  /* Internet Explorer 10+ */
  }

tr { 
  background-color: white;
}

th {
  background-color: rgb(255, 183, 27, 0.55);
}

tr:nth-child(odd){ 
  background-color: white;
}

tr:nth-child(even){
background-color: rgb(255, 183, 27, 0.15); 
}

/*
#####################
   Table-centered 
#####################
Same as table but with horizontally centered text.


Use as:

.. table:: 
  :class: table-centered

  +---------------------------+-------------------+
  |                           | MAPDL Command     |
  +===========================+===================+
  | **GUI commands**          | * ``*ASK``        |
  |                           +-------------------+
  |   ...
  |   ...


*/
table.table-centered {
  width:100%;
  max-width: 100%; 
  border-spacing: 0;
  border-collapse: collapse;
  overflow: hidden;
  vertical-align: middle;
  text-align: center;

  /* Disabling scroll bars */
  overflow-y: scroll;
  scrollbar-width: none; /* Firefox */
  -ms-overflow-style: none;  /* Internet Explorer 10+ */
  }

.table-centered tr { 
  background-color: white;
  text-align: center;
}

.table-centered th {
  background-color: rgb(255, 183, 27, 0.55);
  text-align: center;
}

.table-centered tr:nth-child(odd){ 
  text-align: center;
  background-color: white;
}

.table-centered tr:nth-child(even){
  background-color: rgb(255, 183, 27, 0.15); 
  text-align: center;
}


/*
###############
   longtable 
###############
*/

table.longtable tr:hover td {
  background-color: rgb(255, 183, 27, 0.6);
}

/*
#########################
   longtable-centered
#########################

Use as:


.. table:: 
  :class: longtable-centered

  +---------------------------+-------------------+
  |                           | MAPDL Command     |
  +===========================+===================+
  | **GUI commands**          | * ``*ASK``        |
  |                           +-------------------+
  |   ...
  |   ...

*/

table.longtable-centered {
  text-align: center;
  }

.longtable-centered tr { 
  text-align: center;
}

.longtable-centered th {
  text-align: center;
}

.longtable-centered tr:nth-child(odd){ 
  text-align: center;
}

.longtable-centered tr:nth-child(even){
  text-align: center;
}

table.longtable-centered tr:hover td {
  background-color: rgb(255, 183, 27, 0.6);
  text-align: center;
}

/*
##############
   DataFrame
##############
Not sure why the odd columns (white) are rendered gray.

I do not think we will be able to call this class.
*/

.dataframe tr{ 
    background-color: white;
  }

.dataframe tr:nth-child(odd){ 
    background-color: white !important;
  }

.dataframe tr:nth-child(even){
  background-color: rgb(255, 183, 27, 0.15);
}

.dataframe tr:hover td {
  background-color: rgb(255, 183, 27, 0.6);
}


/*
#########################
   DataFrame-centered
#########################
Not sure why the odd columns (white) are rendered gray.

I do not think we will be able to call this class.
*/

.dataframe-centered tr{ 
    background-color: white;
    text-align: center;
  }

.dataframe-centered tr:nth-child(odd){ 
    background-color: white !important;  
    text-align: center;
  }

.dataframe-centered tr:nth-child(even){
  background-color: rgb(255, 183, 27, 0.15);
  text-align: center;
}

.dataframe-centered tr:hover td {
  background-color: rgb(255, 183, 27, 0.6);
  text-align: center;
}

.dataframe thead th {
    text-align: center;
}



/*
###############
   Autosummary 
###############
*/
/* .autosummary {
        text-align: left;
        } */

.autosummary  tr:nth-child(odd){ 
    background-color: white;
  }

.autosummary tr:nth-child(even){
  background-color: white;
}


/*
########################
   ReST :download: links
########################
*/
a > code.download
{
    font-family: var(--pst-font-family-base);
    color: var(--pst-color-link);
    text-decoration: none;
    font-weight: normal;
}
